<?php
/**
 * $Horde: ingo/filters.php,v 1.14.2.6 2005/01/03 11:25:53 jan Exp $
 *
 * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file LICENSE for license information. If you
 * did not receive this file, see http://www.horde.org/licenses.
 */

@define('INGO_BASE', dirname(__FILE__));
require_once INGO_BASE . '/lib/base.php';

/* Redirect to prefs if rules are turned off. */
if (!$prefs->getValue('show_rules')) {
    header('Location: ' . Horde::applicationUrl('prefs.php', true));
    exit;
}

/* Get the list of rules. */
$rules = $ingo['storage']->retrieve('rules');

/* Get web parameter data. */
$actionID = Horde::getFormData('actionID');
if ($actionID == INGO_RULE_NEW) {
    $rules[] = array();
    $id = max(array_keys($rules));
} else {
    $id = Horde::getFormData('rulenumber');
}

/* Perform requested actions. */
switch ($actionID) {
case INGO_RULE_EDIT:
case INGO_RULE_NEW:
    $_SESSION['ingo']['edit'] = $id;
    header('Location: ' . Horde::applicationUrl('rule.php'));
    exit;

case INGO_RULE_DELETE:
case INGO_RULE_COPY:
case INGO_ACTION_UP:
case INGO_ACTION_DOWN:
    switch ($actionID) {
    case INGO_RULE_DELETE:
    case INGO_RULE_COPY:
        if (isset($rules[$id])) {
            if ($actionID == INGO_RULE_DELETE) {
                unset($rules[$id]);
                $rules = array_values($rules);
                $notification->push(_("Rule Deleted"), 'horde.success');
            } else {
                $rules = array_merge(array_slice($rules, 0, $id + 1),
                                     array(array('name' => sprintf(_("Copy of %s"), $rules[$id]['name']))),
                                     array_slice($rules, $id + 1));
                $notification->push(_("Rule Copied"), 'horde.success');
            }
        }
        break;

    case INGO_ACTION_UP:
        if ($id > 0) {
            $temp = $rules[$id - 1];
            $rules[$id - 1] = $rules[$id];
            $rules[$id] = $temp;
        }
        break;

    case INGO_ACTION_DOWN:
        if ($id < (count($rules) - 1)) {
            $temp = $rules[$id + 1];
            $rules[$id + 1] = $rules[$id];
            $rules[$id] = $temp;
        }
        break;
    }

    /* Save changes */
    $ingo['storage']->store('rules', $rules);
    if ($prefs->getValue('auto_update')) {
        Ingo::updateScript();
    }
    break;
}

require INGO_TEMPLATES . '/common-header.inc';
include INGO_BASE . '/menu.php';
$notification->notify();
require INGO_TEMPLATES . '/filters/header.inc';

if (count($rules) == 0) {
    require INGO_TEMPLATES . '/filters/filter-none.inc';
} else {
    $i = 0;
    $filters_url = Horde::applicationUrl('filters.php');
    $rule_count = count($rules);

    foreach ($rules as $rule_number => $filter) {
        $url = Horde::addParameter($filters_url, 'rulenumber=' . $rule_number);
        $editurl = Horde::addParameter($url, 'actionID=' . INGO_RULE_EDIT);
        $delurl  = Horde::addParameter($url, 'actionID=' . INGO_RULE_DELETE);
        $copyurl = Horde::addParameter($url, 'actionID=' . INGO_RULE_COPY);
        $upurl   = Horde::addParameter($url, 'actionID=' . INGO_ACTION_UP);
        $downurl = Horde::addParameter($url, 'actionID=' . INGO_ACTION_DOWN);
        $i++;
        switch ($filter['action']) {
        case INGO_STORAGE_ACTION_BLACKLIST:
            require INGO_TEMPLATES . '/filters/blacklist.inc';
            break;

        case INGO_STORAGE_ACTION_WHITELIST:
            require INGO_TEMPLATES . '/filters/whitelist.inc';
            break;

        case INGO_STORAGE_ACTION_VACATION:
            if (!$prefs->getValue('show_vacation')) {
                continue;
            }
            require INGO_TEMPLATES . '/filters/vacation.inc';
            break;

        default:
            require INGO_TEMPLATES . '/filters/filter.inc';
            break;
        }
    }
}

require INGO_TEMPLATES . '/filters/footer.inc';
require INGO_TEMPLATES . '/common-footer.inc';
