<?php
/**
 * Ingo_Driver_vfs:: Implements an Ingo storage driver using Horde VFS.
 *
 * Copyright 2003-2005 Brent J. Nordquist <bjn@horde.org>
 *
 * See the enclosed file LICENSE for license information. If you
 * did not receive this file, see http://www.horde.org/licenses.
 *
 * $Horde: ingo/lib/Driver/vfs.php,v 1.4.2.2 2005/01/03 11:25:55 jan Exp $
 *
 * @author  Brent J. Nordquist <bjn@horde.org>
 * @version $Revision: 1.4.2.2 $
 * @since   Ingo 0.0.1
 * @package ingo
 */

class Ingo_Driver_vfs extends Ingo_Driver {

    /**
     * Constructs a new VFS-based storage driver.
     *
     * @access public
     *
     * @param array $params  A hash containing driver parameters.
     */
    function Ingo_Driver_vfs($params = array())
    {
        $this->_params = array();
        $this->_params['vfstype'] = isset($params['vfstype']) ? $params['vfstype'] : 'ftp';
        $this->_params['hostspec'] = isset($params['hostspec']) ? $params['hostspec'] : 'localhost';
        $this->_params['port'] = isset($params['port']) ? $params['port'] : 21;
        $this->_params['procmailrc'] = isset($params['procmailrc']) ? $params['procmailrc'] : '.procmailrc';
    }

    /**
     * Sets a script running on the backend.
     *
     * @param string $script  The filter script
     *
     * @return mixed  True on success, or PEAR_Error on failure.
     */
    function setScriptActive($script, $username, $password)
    {
        if ($this->_params['vfstype'] != 'ftp') {
            return PEAR::raiseError(_(sprintf("VFS type '%s' not yet implemented.", $this->_params['vfstype'])));
        }
        $this->_params['username'] = $username;
        $this->_params['password'] = $password;

        require_once HORDE_BASE . '/lib/VFS.php';
        $vfs = &Horde_VFS::singleton($this->_params['vfstype'], $this->_params);
        $res = $vfs->writeData('', $this->_params['procmailrc'], $script);
        $vfs->_disconnect();
        if (PEAR::isError($res)) {
            return $res;
        }
        return true;
    }

    /**
     * Used to determine the capabilities of the server the
     * script will be run on.
     *
     * @param string $name  The name of the extension.
     *
     * @return boolean  True if the server has the extension, else false.
     */
    function hasExtension($name)
    {
        return false;
    }

}
