<?php

// Actions
/** @const INGO_ACTION_UP Move an action up.      */ define('INGO_ACTION_UP', 101);
/** @const INGO_ACTION_DOWN Move an action down.  */ define('INGO_ACTION_DOWN', 102);
/** @const INGO_ACTION_DELETE Delete an action.   */ define('INGO_ACTION_DELETE', 103);
/** @const INGO_ACTION_ADD Add a new action.      */ define('INGO_ACTION_ADD', 104);
/** @const INGO_ACTION_SAVE Save an action.       */ define('INGO_ACTION_SAVE', 105);
/** @const INGO_ACTION_ACTIVATE Enable the filter.*/ define('INGO_ACTION_ACTIVATE', 106);

/** @const INGO_TEST_SAVE Save an test.          */ define('INGO_TEST_SAVE', 151);
/** @const INGO_TEST_EDIT Edit an test.          */ define('INGO_TEST_EDIT', 152);

/** @const INGO_EDIT_ACTIONS Edit Actions.       */ define('INGO_EDIT_ACTIONS', 201);
/** @const INGO_SAVE_ACTIONS Save Actions.       */ define('INGO_SAVE_ACTIONS', 202);
/** @const INGO_ELSIF_ADD Add an Elsif           */ define('INGO_ELSIF_ADD', 203);
/** @const INGO_ELSIF_DELETE Delete an Elsif     */ define('INGO_ELSIF_DELETE', 204);

/** @const INGO_RULE_SAVE Save a rule.           */ define('INGO_RULE_SAVE', 301);
/** @const INGO_RULE_UPDATE Update a rule.       */ define('INGO_RULE_UPDATE', 302);
/** @const INGO_RULE_EDIT Edit a rule.           */ define('INGO_RULE_EDIT', 303);
/** @const INGO_RULE_NEW Add new rule.           */ define('INGO_RULE_NEW', 304);
/** @const INGO_RULE_DELETE Delete a rule.       */ define('INGO_RULE_DELETE', 305);
/** @const INGO_RULE_COPY Copy a rule.           */ define('INGO_RULE_COPY', 306);

/**
 * @const INGO_BLACKLIST_MARKER
 * String that can't be a valid folder name used to mark blacklisted
 * email as deleted.
 */
define('INGO_BLACKLIST_MARKER', '++DELETE++');

/**
 * Ingo base class.
 *
 * $Horde: ingo/lib/Ingo.php,v 1.32.2.5 2003/05/18 10:43:59 jan Exp $
 *
 * @author  Mike Cochrane <mike@graftonhall.co.nz>
 * @version $Revision: 1.32.2.5 $
 * @since   Ingo 1.0
 * @package ingo
 */
class Ingo {

    /**
     * Generates a folder widget.
     * If an application is available that provides a folderlist method
     * then a &lt;select&gt; input is created else a simple text field
     * is returned.
     *
     * @access public
     *
     * @param optional string $value  The current value for the field.
     *
     * @return string  The HTML to render the field.
     */
    function flistSelect($value = null)
    {
        global $registry;

        $mailboxes = $registry->call('mail/folderlist');

        if (!PEAR::isError($mailboxes)) {
            require_once HORDE_BASE . '/lib/Text.php';
            $options = '<select name="actionvalue">';
            $options .= '<option value="">' . _("Select Target Folder") . "</option>\n";

            foreach ($mailboxes as $mbox) {
                $sel = ($mbox['val'] && ($mbox['val'] === $value)) ? ' selected="selected"' : '';
                $val = htmlspecialchars($mbox['val']);
                $label = $mbox['abbrev'];
                $options .= sprintf('<option value="%s"%s>%s</option>%s', $val, $sel, Text::htmlSpaces($label), "\n");
            }

            $options .= '</select>';
            return $options;
        } else {
            return '<input name="actionvalue" size="40" value="' . $value . '" />';
        }
    }

    /**
     * Connects to a backend and uploads the script and sets it
     * active.
     *
     * @access public
     *
     * @param string $script  The script to set active.
     */
    function activateScript($script)
    {
        global $notification;

        $backend = Ingo::getBackend();
        if (PEAR::isError($backend)) {
            $notification->push($backend->getMessage(), 'horde.error');
            return false;
        } elseif (empty($backend['script'])) {
            $notification->push(sprintf(_("No '%s' element found in backend configuration."), 'script'), 'horde.error');
            return false;
        }

        $uid = Auth::getAuth();
        if (($backend['hordeauth'] == 'user') &&
            (($pos = strpos($uid, '@')) !== false)) {
            $uid = substr($uid, 0, $pos);
        }

        require_once INGO_BASE . '/lib/Driver.php';
        if (empty($backend['driver'])) {
            $notification->push(sprintf(_("No '%s' element found in backend configuration."), 'driver'), 'horde.error');
        } else {
            $driver = &Ingo_Driver::singleton($backend['driver'], $backend['params']);
            $res = $driver->setScriptActive($script, $uid, Auth::getCredential('password'));
            if (!PEAR::isError($res)) {
                $notification->push(_("Script successfully activated."), 'horde.success');
            } else {
                $notification->push(sprintf(_("There was an error activating this script. The driver said: %s"), $res->getMessage()), 'horde.error');
            }
        }
    }

    /**
     * Determine the backend to use.
     *
     * This decision is based on the global 'SERVER_NAME' and 'HTTP_HOST'
     * server variables and the contents of the 'preferred' either field
     * in the backend's definition.  The 'preferred' field may take a
     * single value or an array of multiple values.
     *
     * @access public
     *
     * @return array  The backend entry.
     *                Returns PEAR_Error on error.
     */
    function getBackend()
    {
        static $backend;

        if (isset($backend)) {
            return $backend;
        }

        /* Choose a backend */
        include INGO_BASE . '/config/backends.php';
        if (!isset($backends) || !is_array($backends)) {
            return PEAR::raiseError(_("No backends configured"));
        }
        foreach ($backends as $temp) {
            if (!isset($backend)) {
                $backend = $temp;
            } elseif (!empty($temp['preferred'])) {
                if (is_array($temp['preferred'])) {
                    foreach ($temp['preferred'] as $val) {
                        if (($val == $_SERVER['SERVER_NAME']) ||
                            ($val == $_SERVER['HTTP_HOST'])) {
                            $backend = $temp;
                        }
                    }
                } elseif (($temp['preferred'] == $_SERVER['SERVER_NAME']) ||
                          ($temp['preferred'] == $_SERVER['HTTP_HOST'])) {
                    $backend = $temp;
                }
            }
        }

        if (!isset($backend)) {
            return PEAR::raiseError(_("No backend configured for this host"));
        } else {
            return $backend;
        }
    }

    /**
     * Does all the work in updating the script on the server.
     *
     * @access public
     */
    function updateScript()
    {
        global $notification;

        $scriptor = &Ingo::loadIngoScript();
        if (!$scriptor) {
            $notification->push(_("Script not updated."), 'horde.error');
        } else {
            /* Generate and activate the script. */
            $script = $scriptor->generate();
            Ingo::activateScript($script);
        }
    }

    /**
     * Loads a Ingo_Script:: backend and checks for errors.
     *
     * @access public
     *
     * @return mixed  Ingo_Script:: object on success, false on failure.
     */
    function &loadIngoScript()
    {
        global $notification;

        $backend = Ingo::getBackend();
        if (PEAR::isError($backend)) {
            $notification->push($backend->getMessage(), 'horde.error');
            return false;
        } elseif (empty($backend['script'])) {
            $notification->push(sprintf(_("No '%s' element found in backend configuration."), 'script'), 'horde.error');
            return false;
        }

        require_once INGO_BASE . '/lib/Script.php';
        $scriptor = &Ingo_Script::singleton($backend['script']);
        if (PEAR::isError($scriptor)) {
            $notification->push($scriptor->getMessage(), 'horde.error');
            return false;
        }

        return $scriptor;
    }

}
