<?php
/**
 * Ingo_Storage_prefs:: implements the Ingo_Storage:: API to save Ingo data
 * via the Horde preferences system.
 *
 * $Horde: ingo/lib/Storage/prefs.php,v 1.5.2.3 2003/04/28 18:10:45 slusarz Exp $
 *
 * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
 * @version $Revision: 1.5.2.3 $
 * @since   Ingo 0.1
 * @package ingo
 */
class Ingo_Storage_prefs extends Ingo_Storage {

    /**
     * Constructor.
     *
     * @access public
     */
    function Ingo_Storage_prefs($params = array())
    {
        $this->_params = $params;
    }

    /**
     * Retrieve the specified data.
     *
     * @access public
     *
     * @param string $field  The field name of the desired data.
     *                       See above for the available fields.
     *
     * @return array  The specified data.
     */
    function retrieve($field)
    {
        global $prefs;

        switch (strtolower($field)) {
        case 'blacklist':
        case 'rules':
        case 'vacation':
        case 'whitelist':
            return unserialize($prefs->getValue($field));
            break;

        case 'blacklist_folder':
            return $prefs->getValue($field);
            break;

        default:
            return false;
            break;
        }
    }

    /**
     * Store the specified data.
     *
     * @access public
     *
     * @param string $field  The field name to store the desired data.
     *                       See above for the available fields.
     * @param mixed $data    The data to store.
     *
     * @return boolean  True on success.
     */
    function store($field, $data)
    {
        global $prefs;

        switch (strtolower($field)) {
        case 'rules':
        case 'vacation':
            $ret = $prefs->setValue($field, serialize($data));
            break;

        case 'blacklist':
            $ret = $prefs->setValue($field, serialize($this->_prepareAddressList($data)));
            break;

        case 'blacklist_folder':
            $ret = $prefs->setValue($field, $data);
            break;

        case 'whitelist':
            $ret = $prefs->setValue($field, serialize($this->_prepareAddressList($data)));
            break;

        default:
            $ret = false;
            break;
        }

        /* Write prefs out to persistent storage. */
        if ($ret == true) {
            $ret = $prefs->store();
            $ret = PEAR::isError($ret) ? false : true;
        }

        return $ret;
    }

    /**
     * Is this field locked?
     *
     * @access public
     *
     * @param string $field  The field name to store the desired data.
     *                       See above for the available fields.
     *
     * @return boolean  Whether the field is locked or not.
     */
    function isLocked($field)
    {
        global $prefs;

        return $prefs->isLocked(strtolower($field));
    }

}
