<?php
/**
 * $Horde: ingo/rule.php,v 1.23.2.3 2005/01/03 11:25:53 jan Exp $
 *
 * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file LICENSE for license information. If you
 * did not receive this file, see http://www.horde.org/licenses.
 */

define('INGO_BASE',  dirname(__FILE__));
require_once INGO_BASE . '/lib/base.php';
require_once INGO_BASE . '/lib/Driver.php';
require INGO_BASE . '/config/tests.php';

/* Redirect to prefs if rules are turned off. */
if (!$prefs->getValue('show_rules')) {
    header('Location: ' . Horde::applicationUrl('prefs.php', true));
    exit;
}

$filter = &$_SESSION['ingo']['filters'][$_SESSION['ingo']['edit']];

/* Set up default values... */
$default_filters = array(
    'name' => _("New Rule"),
    'combine' => INGO_STORAGE_COMBINE_ALL,
    'conditions' => array(),
    'action' => INGO_STORAGE_ACTION_KEEP,
    'action-value' => '',
    'stop' => false,
    'flags' => array()
);
$filter = array_merge($default_filters, $filter);

/* Action descriptions. */
$actions = array(
    INGO_STORAGE_ACTION_KEEP => array(
        'label' => _("Deliver this message into my INBOX"),
        'type' => false,
        'flags' => true
    ),
    INGO_STORAGE_ACTION_MOVE => array(
        'label' => _("Deliver to this mailbox"),
        'type' => 'folder',
        'flags' => true
    ),
    INGO_STORAGE_ACTION_DISCARD => array(
        'label' => _("Discard this message"),
        'type' => false
    ),
    INGO_STORAGE_ACTION_REDIRECT => array(
        'label' => _("Redirect this message to"),
        'type' => 'text'
    ),
    INGO_STORAGE_ACTION_REDIRECTKEEP => array(
        'label' => _("Deliver into my INBOX and Redirect to"),
        'type' => 'text',
        'flags' => true
    ),
    INGO_STORAGE_ACTION_REJECT => array(
        'label' => _("Reject this message with reason"),
        'type' => 'text'
    )
);

/* Load the Ingo_Script:: driver. */
$ingo_script = &Ingo::loadIngoScript();

function actionSelect($selected = null)
{
    global $actions, $ingo_script;

    $actionselect = '';

    $actionlist = ($ingo_script) ? $ingo_script->availableActions() : array_keys($actions);
   
    foreach ($actionlist as $val) {
        $actionselect .= '<option value="' . $val . '"';
        if ($val == $selected) {
            $actionselect .= ' selected';
        }
        $actionselect .= '>' . $actions[$val]['label'] . "</option>\n";
    }

    return $actionselect;
}


function actionValue($action, $value = '')
{
    global $actions;

    switch ($actions[$action]['type']) {
    case 'folder':
        return Ingo::flistSelect($value);
        break;
    case 'text':
    case 'int':
        $third = '<input name="actionvalue" size="40" value="' . $value . '" />';
        return $third;
        break;
    }

    return '';
}

function fieldSelect($selected = null, $header = false) {
    global $fields;

    $fieldselect = '';
    if ($header) {
        $fieldselect .= '<option value="">' . _("Select a field") . "</option>\n";
        $fieldselect .= "<option value=\"\"> --------- </option>\n";
    }
    foreach ($fields as $key => $field) {
        $fieldselect .= '<option value="' . $key . '"';
        if ($key == $selected) {
            $fieldselect .= ' selected';
        }
        $fieldselect .= '>' . $field['label'] . "</option>\n";
    }

    return $fieldselect;
}

function matchSelect($field, $selected = null) {
    global $fields, $ingo_script, $tests;

    $matchselect = '';

    $avail_tests = array_intersect($ingo_script->availableTests(), $fields[$field]['tests']);
    if (empty($avail_tests)) {
        $matchselect = "<option value=\"\"> --------- </option>\n";
    } else {
        foreach ($avail_tests as $test) {
            $matchselect .= '<option value="' . $test . '"';
            if ($test == $selected) {
                $matchselect .= ' selected';
            }
            $matchselect .= '>' . $tests[$test]['label'] . "</option>\n";
        }
    }

    return $matchselect;
}

function third($filter_number, $field, $match, $value = '', $case = '') {
    global $fields;
    global $tests;

    $third = '';
    $value = htmlspecialchars($value);
    switch ($tests[$match]['type']) {
    case 'text':
        $third = '<input name="value[' . $filter_number . ']" size="40" value="' . $value . '" />';
        $third .= '<input type="checkbox" name="case[' . $filter_number . ']" value="1" ';
        $third .= ($case) ? 'checked' : '';
        $third .= '/> ' . _("Case Sensitive");
        break;
    case 'int':
        $third = '<input name="value[' . $filter_number . ']" size="40" value="' . $value . '" />';
        break;
    }

    return $third;
}

$actionID = Horde::getFormData('actionID');
switch ($actionID) {
case INGO_RULE_DELETE;
case INGO_RULE_SAVE:
case INGO_RULE_UPDATE:
    $filter['name'] = Horde::getFormData('name');
    $filter['combine'] = Horde::getFormData('combine');
    $filter['conditions'] = array();

    $first = Horde::getFormData('field');
    $second = Horde::getFormData('match');
    $third = Horde::getFormData('value');
    $forth = Horde::getFormData('case');
    foreach ($first as $key => $field) {
        if (!empty($field)) {
            $condition = array();
            $condition['field'] = $field;
            $condition['match'] = $second[$key];
            $condition['value'] = isset($third[$key]) ? $third[$key] : '';
            $condition['case'] = isset($forth[$key]) ? $forth[$key] : '';
            $filter['conditions'][] = $condition;
        }
    }

    $filter['action'] = Horde::getFormData('action');
    $filter['action-value'] = Horde::getFormData('actionvalue');
    $filter['stop'] = Horde::getFormData('stop');
    $filter['flags'] = Horde::getFormData('flags', array());

    if ($actionID == INGO_RULE_SAVE) {
        $ingo['storage']->store('rules', $_SESSION['ingo']['filters']);
        $notification->push(_("Changes Saved"), 'horde.success');

        if ($prefs->getValue('auto_update')) {
            Ingo::updateScript();
        }
        header('Location: ' . Horde::applicationUrl('filters.php'));
        exit;
    }

    if ($actionID == INGO_RULE_DELETE) {
        $rule_number = Horde::getFormData('rulenumber');
        $conditions = array();
        foreach ($filter['conditions'] as $key => $condition) {
            if ($key != $rule_number) {
                $conditions[] = $condition;
            }
        }
        $filter['conditions'] = $conditions;
    }

    break;
}

require INGO_TEMPLATES . '/common-header.inc';
require INGO_BASE . '/menu.php';
$notification->notify();
require INGO_TEMPLATES . '/rules/header.inc';

/* Display the conditions. */
$filter_number = -1;
foreach ($filter['conditions'] as $filter_number => $condition) {
    $display_delete = true;
    $field_select = fieldSelect($condition['field']);
    $match_select = matchSelect($condition['field'], $condition['match']);
    $third = third($filter_number, $condition['field'], $condition['match'], $condition['value'], $condition['case']);
    require INGO_TEMPLATES . '/rules/filter.inc';
}

/* display a new empty condition */
$filter_number++;
$display_delete = false;
$field_select = fieldSelect(null, true);
$match_select = matchSelect('Subject');
$third = third($filter_number, 'Subject', 'contains');

require INGO_TEMPLATES . '/rules/filter.inc';
require INGO_TEMPLATES . '/rules/footer.inc';
require INGO_TEMPLATES . '/common-footer.inc';
